from distutils.core import setup

setup(
    name         = 'asciiTUI',
    version      = '1.2.1',
    author       = 'azzammuhyala',
    author_email = 'azzammuhyala@gmail.com',
    description  = 'This is a library of tools for you to use with your needs for an attractive type of terminal (console) display.',
    url          = 'https://github.com/azzammuhyala/asciiTUI',
    packages     = ['asciiTUI']
)